@@ -55,7 +55,7 @@ KDiff3Shell::KDiff3Shell(bool bCompleteInit)
     {
         // now that the Part is loaded, we cast it to a Part to get
         // our hands on it
-        m_part = static_cast<KParts::ReadWritePart *>(factory->create(TQT_TQOBJECT(this),
+        m_part = static_cast<KParts::ReadWritePart *>(factory->create(this,
                                 "kdiff3_part", "KParts::ReadWritePart" ));
 
         if (m_part)
@@ -68,7 +68,7 @@ KDiff3Shell::KDiff3Shell(bool bCompleteInit)
 
             if (bCompleteInit)
                ((KDiff3App*)m_part->widget())->completeInit();
-            connect(((KDiff3App*)m_part->widget()), TQT_SIGNAL(createNewInstance(const TQString&, const TQString&, const TQString&)), this, TQT_SLOT(slotNewInstance(const TQString&, const TQString&, const TQString&)));
+            connect(((KDiff3App*)m_part->widget()), TQ_SIGNAL(createNewInstance(const TQString&, const TQString&, const TQString&)), this, TQ_SLOT(slotNewInstance(const TQString&, const TQString&, const TQString&)));
         }
     }
     else
@@ -164,8 +164,8 @@ void KDiff3Shell::optionsConfigureToolbars()
 
     // use the standard toolbar editor
     KEditToolbar dlg(factory());
-    connect(&dlg, TQT_SIGNAL(newToolbarConfig()),
-            this, TQT_SLOT(applyNewToolbarConfig()));
+    connect(&dlg, TQ_SIGNAL(newToolbarConfig()),
+            this, TQ_SLOT(applyNewToolbarConfig()));
     dlg.exec();
 }
 
